@@ -21,7 +21,6 @@ from py4j.java_gateway import JavaObject
 from ai.h2o.sparkling.Initializer import Initializer
 from ai.h2o.sparkling.ml.models.H2OMOJOSettings import H2OMOJOSettings
 from ai.h2o.sparkling.ml.params.H2OTypeConverters import H2OTypeConverters
-from ai.h2o.sparkling.H2ODataFrameConverters import H2ODataFrameConverters
 from ai.h2o.sparkling.ml.params.HasMonotoneConstraintsOnMOJO import HasMonotoneConstraintsOnMOJO
 from ai.h2o.sparkling.ml.params.HasIgnoredColsOnMOJO import HasIgnoredColsOnMOJO
 
@@ -156,11 +155,6 @@ class H2OXGBoostMOJOModel(H2OTreeBasedSupervisedMOJOModelParams, HasMonotoneCons
         return value
 
 
-    def getCalibrationMethod(self):
-        value = self._java_obj.getCalibrationMethod()
-        return value
-
-
     def getMaxBins(self):
         value = self._java_obj.getMaxBins()
         return value
@@ -350,5 +344,4 @@ class H2OXGBoostMOJOModel(H2OTreeBasedSupervisedMOJOModelParams, HasMonotoneCons
         value = self._java_obj.getAucType()
         return value
 
-    # Outputs
 
