@@ -23,11 +23,11 @@ from ai.h2o.sparkling.ml.models import H2OKMeansMOJOModel, H2OGLMMOJOModel, H2OG
 from ai.h2o.sparkling.ml.models import H2ODeepLearningMOJOModel, H2OAutoEncoderMOJOModel, H2ODRFMOJOModel
 from ai.h2o.sparkling.ml.models import H2OCoxPHMOJOModel, H2OGLRMMOJOModel, H2ORuleFitMOJOModel
 from ai.h2o.sparkling.ml.models import H2OXGBoostMOJOModel, H2OIsolationForestMOJOModel, H2OPCAMOJOModel
-from ai.h2o.sparkling.ml.models import H2OWord2VecMOJOModel, H2OStackedEnsembleMOJOModel
+from ai.h2o.sparkling.ml.models import H2OWord2VecMOJOModel
 
 __all__ = ["H2OMOJOSettings", "H2OMOJOPipelineModel", "H2OMOJOModel", "H2OAlgorithmMOJOModel", "H2OFeatureMOJOModel",
            "H2OSupervisedMOJOModel", "H2OTreeBasedSupervisedMOJOModel", "H2OUnsupervisedMOJOModel",
            "H2OTreeBasedUnsupervisedMOJOModel", "H2OKMeansMOJOModel", "H2OGLMMOJOModel", "H2OGAMMOJOModel",
            "H2OGBMMOJOModel", "H2OXGBoostMOJOModel", "H2ODeepLearningMOJOModel", "H2OAutoEncoderMOJOModel",
            "H2ODRFMOJOModel", "H2OIsolationForestMOJOModel", "H2OCoxPHMOJOModel", "H2OBinaryModel", "H2OPCAMOJOModel",
-           "H2OGLRMMOJOModel", "H2ORuleFitMOJOModel", "H2OWord2VecMOJOModel", "H2OStackedEnsembleMOJOModel"]
+           "H2OGLRMMOJOModel", "H2ORuleFitMOJOModel", "H2OWord2VecMOJOModel"]
